"use strict";

var __importDefault = void 0 && (void 0).__importDefault || function (mod) {
  return mod && mod.__esModule ? mod : {
    "default": mod
  };
};
Object.defineProperty(exports, "__esModule", {
  value: true
});
var classnames_1 = __importDefault(require("classnames"));
var react_1 = __importDefault(require("react"));
var selection_context_1 = __importDefault(require("../contexts/selection-context"));
var utils_1 = __importDefault(require("../utils"));
var SelectionContext = (0, selection_context_1["default"])();
function withRowSelection(Component) {
  var renderWithSelection = function renderWithSelection(props, selectRow) {
    if (!selectRow) {
      return null;
    }
    var key = props.value;
    var selected = utils_1["default"].contains(selectRow.selected, key);
    var selectable = !selectRow.nonSelectable || !utils_1["default"].contains(selectRow.nonSelectable, key);
    var notSelectable = utils_1["default"].contains(selectRow.nonSelectable, key);
    var style = props.style,
      className = props.className;
    if (selected) {
      var selectedStyle = utils_1["default"].isFunction(selectRow.style) ? selectRow.style(props.row, props.rowIndex) : selectRow.style;
      var selectedClasses = utils_1["default"].isFunction(selectRow.classes) ? selectRow.classes(props.row, props.rowIndex) : selectRow.classes;
      style = Object.assign(Object.assign({}, style), selectedStyle);
      className = (0, classnames_1["default"])(className, selectedClasses) || undefined;
      if (selectRow.bgColor) {
        style = style || {};
        style.backgroundColor = utils_1["default"].isFunction(selectRow.bgColor) ? selectRow.bgColor(props.row, props.rowIndex) : selectRow.bgColor;
      }
    }
    if (notSelectable) {
      var notSelectableStyle = utils_1["default"].isFunction(selectRow.nonSelectableStyle) ? selectRow.nonSelectableStyle(props.row, props.rowIndex) : selectRow.nonSelectableStyle;
      var notSelectableClasses = utils_1["default"].isFunction(selectRow.nonSelectableClasses) ? selectRow.nonSelectableClasses(props.row, props.rowIndex) : selectRow.nonSelectableClasses;
      style = Object.assign(Object.assign({}, style), notSelectableStyle);
      className = (0, classnames_1["default"])(className, notSelectableClasses) || undefined;
    }
    return react_1["default"].createElement(Component, Object.assign({}, props, {
      style: style,
      className: className,
      selectRow: selectRow,
      selected: selected,
      selectable: selectable
    }));
  };
  var WithSelectionRowConsumer = function WithSelectionRowConsumer(props) {
    return react_1["default"].createElement(SelectionContext.Consumer, null, function (selectRow) {
      return renderWithSelection(props, selectRow);
    });
  };
  WithSelectionRowConsumer.displayName = "WithSelectionRowConsumer";
  return WithSelectionRowConsumer;
}
exports["default"] = withRowSelection;